# MkDocs Ansible Collection

MkDocs Plugin that automatically generates pages for Ansible Collections. Uses metadata exported by the `ansible-doc` tool.

## Work in Progress

This plugin is under initial development - you can track progress towards the first functional release [here](https://github.com/cmsirbu/mkdocs-ansible-collection/milestone/1).

Its latest functionality can be seen live on the [docs website](https://mkdocs-ansible-collection.readthedocs.io/en/latest/).

## Developing

To set up the development environment, run the following commands in the project root:

```
poetry install
poetry run mkdocs serve
```
